==> hp300_1.0.tar: hp300/examples/concepts/if.ex <==
#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
(revision "A.00.00")
(date "Thu 11/Apr/1991")
(component 0 "Context"
 (name "If/Then Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "IfThenElse"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else If")
     (lock name constraints)
    )
    (output 3
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "(A>B)")
    (component expr "(A<B)")
   )
   (views
    (icon
     (origin 171 148)
     (extent 78 25)
    )
    (detail
     (origin 275 418)
     (extent 91 104)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 1 "Constant"
   (name "B")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "B")
     (datum 5)
    )
    (component autoTrigger on)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
   )
   (views
    (icon
     (extent 46 0)
    )
    (detail
     (origin 25 486)
     (extent 150 28)
     (showFormat int)
    )
    (active detail)
   )
  )
  (component 2 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 535 383)
     (extent 190 35)
    )
    (active detail)
   )
  )
  (component 3 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 535 463)
     (extent 190 35)
    )
    (active detail)
   )
  )
  (component 4 "Constant"
   (name "A")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "A")
     (datum 4)
    )
    (component autoTrigger on)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
   )
   (views
    (icon
     (extent 46 0)
    )
    (detail
     (origin 25 406)
     (extent 150 28)
     (showFormat int)
    )
    (active detail)
   )
  )
  (component 5 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 535 543)
     (extent 190 35)
    )
    (active detail)
   )
  )
  (component 6 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 479 118)
     (extent 382 84)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 7 "Note"
   (name "Overview of \"if\" Example")
   (interface
   )
   (implementation
    (component text 28 5
     Purpose:
     To illustrate the use of the "If/Then" object.
     
     Press Run to start the model.
     A 1 will appear in the display attached to the
     whichever of the lines of the If/Then 
     evaluates to "True".  
      
     Explanation:
     The "If/Then" object evaluates each expression
     in the order they appear.  If one of the 
     expressions evaluates to a True condition the
     that output pin is fired and the If/Then stops
     executing.  The number on the output pin
     is the result of the expresion evaluation.
     
     If none of the expressions evaluates True
     then the "Else" pin is fired. 
     
     Note: The TRUE condition means "non-zero".
     
     For example, if A was 4 and B was 5, then 
     (A==B) would evaluate FALSE and return 0. 
     Just having the expression "A" would return
     4 and thus would evaluate to TRUE, with the
     value of 4 being put on the output pin.
     Likewise (A<B)*10 would evaluate TRUE and 
     fire the output pin with the value of 10 on it.
    )
   )
   (views
    (icon
     (extent 226 0)
    )
    (detail
     (origin 4 116)
     (extent 453 208)
     (editing disabled)
    )
    (active detail)
   )
  )
  (configuration
   (connect D4:1 D0:1)
   (connect D1:1 D0:2)
   (connect D0:1 D2:1)
   (connect D0:2 D3:1)
   (connect D0:3 D5:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 984 651)
   (configuration
    (connect D4:1 D0:1
     (Point 177 420)
     (Point 200 420)
     (Point 200 440)
     (Point 232 440)
    )
    (connect D1:1 D0:2
     (Point 177 500)
     (Point 232 500)
    )
    (connect D0:1 D2:1
     (Point 448 440)
     (Point 470 440)
     (Point 470 400)
     (Point 532 400)
    )
    (connect D0:2 D3:1
     (Point 448 470)
     (Point 470 470)
     (Point 470 480)
     (Point 532 480)
    )
    (connect D0:3 D5:1
     (Point 448 500)
     (Point 470 500)
     (Point 470 560)
     (Point 532 560)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_1.1.tar: hp300/examples/concepts/if.ex <==
#! /usr/lib/veetest/veetest -r
(revision "A.00.00")
(date "Thu 02/May/1991")
(component 0 "Context"
 (name "If/Then Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "IfThenElse"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (input 2
     (type data)
     (name "B")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else If")
     (lock name constraints)
    )
    (output 3
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "(A>B)")
    (component expr "(A<B)")
   )
   (views
    (icon
     (origin 171 148)
     (extent 78 25)
    )
    (detail
     (origin 275 418)
     (extent 91 104)
    )
    (terminals on)
    (active detail)
   )
  )
  (component 1 "Constant"
   (name "B")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "B")
     (datum 5)
    )
    (component autoTrigger on)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
   )
   (views
    (icon
     (extent 46 0)
    )
    (detail
     (origin 25 486)
     (extent 150 28)
     (showFormat int)
    )
    (active detail)
   )
  )
  (component 2 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 535 383)
     (extent 190 35)
    )
    (active detail)
   )
  )
  (component 3 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 535 463)
     (extent 190 35)
    )
    (active detail)
   )
  )
  (component 4 "Constant"
   (name "A")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (lock name constraints)
    )
   )
   (implementation
    (component value Int32
     (name "A")
     (datum 4)
    )
    (component autoTrigger on)
    (component initializeAtPrerun off)
    (component initializeAtActivate off)
    (component initValue Int32
     (datum 0)
    )
   )
   (views
    (icon
     (extent 46 0)
    )
    (detail
     (origin 25 406)
     (extent 150 28)
     (showFormat int)
    )
    (active detail)
   )
  )
  (component 5 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 535 543)
     (extent 190 35)
    )
    (active detail)
   )
  )
  (component 6 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 479 118)
     (extent 382 84)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 7 "Note"
   (name "Overview of \"if\" Example")
   (interface
   )
   (implementation
    (component text 30 5
     Purpose:
     To illustrate the use of the "If/Then" object.
     
     Press Run to start the model.
     A "1" will appear in the display attached to
     the whichever of the lines of the If/Then 
     evaluates to "True".  If none of the conditions
     are true, then a "0" will appear in the display
     attached to the "else" pin.
      
     Explanation:
     The "If/Then" object evaluates each expression
     in the order they appear.  If one of the 
     expressions evaluates to a True condition the
     that output pin is fired and the If/Then stops
     executing.  The number on the output pin
     is the result of the expresion evaluation.
     
     If none of the expressions evaluates True
     then the "Else" pin is fired. 
     
     Note: The TRUE condition means "non-zero".
     
     For example, if A was 4 and B was 5, then 
     (A==B) would evaluate FALSE and return 0. 
     Just having the expression "A" would return
     4 and thus would evaluate to TRUE, with the
     value of 4 being put on the output pin.
     Likewise (A<B)*10 would evaluate TRUE and 
     fire the output pin with the value of 10 on it.
    )
   )
   (views
    (icon
     (extent 226 0)
    )
    (detail
     (origin 4 116)
     (extent 453 208)
     (editing disabled)
    )
    (active detail)
   )
  )
  (configuration
   (connect D4:1 D0:1)
   (connect D1:1 D0:2)
   (connect D0:1 D2:1)
   (connect D0:2 D3:1)
   (connect D0:3 D5:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 1043 828)
   (configuration
    (connect D4:1 D0:1
     (Point 177 420)
     (Point 200 420)
     (Point 200 440)
     (Point 232 440)
    )
    (connect D1:1 D0:2
     (Point 177 500)
     (Point 232 500)
    )
    (connect D0:1 D2:1
     (Point 448 440)
     (Point 470 440)
     (Point 470 400)
     (Point 532 400)
    )
    (connect D0:2 D3:1
     (Point 448 470)
     (Point 470 470)
     (Point 470 480)
     (Point 532 480)
    )
    (connect D0:3 D5:1
     (Point 448 500)
     (Point 470 500)
     (Point 470 560)
     (Point 532 560)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)
